@@ -1,11 +1,11 @@
 """Data preparation module __init__."""
 from . import build_grid
 from . import layer_encoder
-from . import occurrence_transformation
+from . import occurrence_splitter
 
 __all__ = []
 #    'build_grid', 'layer_encoder', 'occurrence_filters',
 #    'occurrence_transformation']
 __all__.extend(build_grid.__all__)
 __all__.extend(layer_encoder.__all__)
-__all__.extend(occurrence_transformation.__all__)
+__all__.extend(occurrence_splitter.__all__)
