@@ -24,14 +24,10 @@ def cli():
     """Provide a command-line tool for converting lmms to csvs."""
     parser = argparse.ArgumentParser(description=DESCRIPTION)
     parser.add_argument(
-        'in_lmm_filename',
-        type=str,
-        help='Lmpy LMM filename to convert to CSV.'
+        'in_lmm_filename', type=str, help='Lmpy LMM filename to convert to CSV.'
     )
     parser.add_argument(
-        'out_csv_filename',
-        type=str,
-        help='Location to write the converted matrix CSV.'
+        'out_csv_filename', type=str, help='Location to write the converted matrix CSV.'
     )
     args = parser.parse_args()
     mtx = Matrix.load(args.in_lmm_filename)
@@ -43,5 +39,5 @@ __all__ = ['cli', 'convert_lmm_to_csv']
 
 
 # .....................................................................................
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma: no cover
     cli()
